import { BigNumberish, BytesLike, ContractTransaction, ethers, Signer } from "ethers";
import { CompaniesV10 } from "./types";
import { DecodedCall } from "./abiDecoderController";
export declare class CompaniesController {
    private _signer;
    private _companiesAddress;
    private _companiesContract?;
    constructor(_companiesAddress: string, signerOrProvider: Signer | ethers.providers.ExternalProvider);
    private _getCompaniesContract;
    static deployCompaniesContract(signer: Signer, owner: string): Promise<[CompaniesV10, string]>;
    /**Getters */
    getContract(): Promise<CompaniesV10>;
    getAllCompanies(): Promise<Array<string>>;
    isAddressCompany(address: string): Promise<boolean>;
    getCompanyBySignatorie(address: string): Promise<string>;
    getCompanyByAddress(address: string): Promise<[BigNumberish, Array<string>, string, BytesLike, boolean]>;
    getCompanyByName(address: string): Promise<[BigNumberish, Array<string>, string, BytesLike, boolean]>;
    isSignatorieAuthorized(address: string): Promise<boolean>;
    /**Setters */
    addCompany(address: string, name: string, ipfsLink: BytesLike): Promise<ContractTransaction>;
    removeCompany(address: string): Promise<ContractTransaction>;
    addSignatorie(address: string): Promise<ContractTransaction>;
    removeSignatorie(address: string): Promise<ContractTransaction>;
    setCompanyData(name: string, ipfsLink: BytesLike): Promise<ContractTransaction>;
    /** Helpers */
    static encodeCall(functionName: string, args?: any[]): string;
    static decodeCall(data: string): DecodedCall | null;
}
