import { BigNumberish, ContractTransaction, ethers, Signer } from "ethers";
import { DealRoom } from "./types";
import { DecodedCall } from "./abiDecoderController";
export declare type Deal = {
    id: BigNumberish;
    erc20: string;
    erc721: string;
    price: BigNumberish;
    assetItems: BigNumberish[];
    status: number;
    valid: boolean;
};
export declare enum DealStatus {
    Undefined = 0,
    Open = 1,
    Cancelled = 2,
    Settled = 3
}
export declare class DealRoomController {
    private _signer;
    private _dealRoomAddress;
    private _dealRoomContract?;
    constructor(_dealRoomAddress: string, signerOrProvider: Signer | ethers.providers.ExternalProvider);
    private _getDealRoomContract;
    /**Getters */
    getContract(): Promise<DealRoom>;
    getOwner(): Promise<string>;
    getBuyer(): Promise<string>;
    getSeller(): Promise<string>;
    getDeal(id: BigNumberish): Promise<Deal>;
    getDealCount(): Promise<BigNumberish>;
    getDealStatus(id: BigNumberish): Promise<DealStatus>;
    missingDealAssets(id: BigNumberish): Promise<BigNumberish>;
    missingDealCoins(id: BigNumberish): Promise<BigNumberish>;
    /**Setters */
    makeDeal(erc20: string, erc721: string, price: BigNumberish, assets: Array<BigNumberish>): Promise<ContractTransaction>;
    settle(id: BigNumberish): Promise<ContractTransaction>;
    withdrawDealAssets(id: BigNumberish, count: BigNumberish): Promise<ContractTransaction>;
    withdrawDealCoins(id: BigNumberish): Promise<ContractTransaction>;
    /** Helpers */
    static encodeCall(functionName: string, args?: any[]): string;
    static decodeCall(data: string): DecodedCall | null;
}
