import { BigNumberish, ContractTransaction, ethers, Signer } from "ethers";
import { DealRoomHubV10 } from "./types";
import { DecodedCall } from "./abiDecoderController";
export declare type DealRoomCreateParams = {
    dealRoomHubAddress: string;
    buyer: string;
    seller: string;
    arbitrator: string;
    docApprover: string;
    sensorApprover: string;
};
export declare type DealRoomDetails = {
    addr: string;
    buyer: string;
    seller: string;
    arbitrator: string;
    sensorApprover: string;
    docApprover: string;
    dealMultiSig: string;
    agentMultiSig: string;
};
export declare class DealRoomHubController {
    private _signer;
    private _dealRoomHubAddress;
    private _dealRoomHubContract?;
    constructor(_dealRoomHubAddress: string, signerOrProvider: Signer | ethers.providers.ExternalProvider);
    private _getDealRoomHubContract;
    static deployDealRoomHubContract(signer: Signer): Promise<[DealRoomHubV10, string]>;
    /**Getters */
    getContract(): Promise<DealRoomHubV10>;
    getUserRooms(address: string): Promise<Array<string>>;
    getAllRooms(): Promise<Array<string>>;
    getRoom(roomAddress: string): Promise<DealRoomDetails>;
    roomCount(): Promise<BigNumberish>;
    /**Setters */
    makeRoom(params: DealRoomCreateParams): Promise<ContractTransaction>;
    changeOwner(newOwner: string): Promise<ContractTransaction>;
    /** Helpers */
    static encodeCall(functionName: string, args?: any[]): string;
    static decodeCall(data: string): DecodedCall | null;
}
