import { BigNumberish, BytesLike, ContractTransaction, ethers, Signer, Overrides } from "ethers";
import { MultisigWalletV10 } from "./types";
import { DecodedCall } from "./abiDecoderController";
export declare class MultisigController {
    private _signer;
    private _multisigAddress;
    private _multisigContract?;
    constructor(multisigAddress: string, signerOrProvider: Signer | ethers.providers.ExternalProvider);
    static deployMultisigContract(signer: Signer, owners: Array<string>, requirement: BigNumberish): Promise<[MultisigWalletV10, string]>;
    private _getMultisigContract;
    /**Getters */
    getContract(): Promise<MultisigWalletV10>;
    isConfirmed(transactionId: BigNumberish): Promise<boolean>;
    getConfirmationCount(transactionId: BigNumberish): Promise<BigNumberish>;
    getTransactionCount(pending: boolean, executed: boolean): Promise<BigNumberish>;
    getConfirmations(transactionId: BigNumberish): Promise<Array<string>>;
    getTransactionIds(from: BigNumberish, to: BigNumberish, pending: boolean, executed: boolean): Promise<Array<BigNumberish>>;
    getOwners(): Promise<Array<string>>;
    getTransaction(transactionId: BigNumberish): Promise<[string, string, boolean, BigNumberish]>;
    getResourceActionsContract(): Promise<string>;
    getRequiredSignatures(): Promise<BigNumberish>;
    isOwner(address: string): Promise<boolean>;
    /**Setters */
    submitTransaction(destination: string, value: BigNumberish, data: BytesLike, overrides: Overrides): Promise<ContractTransaction>;
    confirmTransaction(transactionId: BigNumberish, overrides: Overrides): Promise<ContractTransaction>;
    revokeConfirmation(transactionId: BigNumberish): Promise<ContractTransaction>;
    executeTransaction(transactionId: BigNumberish): Promise<ContractTransaction>;
    /** Helpers */
    static encodeCall(functionName: string, args?: any[]): string;
    static decodeCall(data: string): DecodedCall | null;
}
