import { BigNumberish, BytesLike, ContractTransaction, ethers, Signer, Overrides } from "ethers";
import { MultiSigHashed } from "./types";
import { DecodedCall } from "./abiDecoderController";
export declare type Transaction = {
    destination: string;
    value: BigNumberish;
    data: string;
    executed: boolean;
    timestamp: BigNumberish;
    hash: string;
};
export declare class MultisigHashedController {
    private _signer;
    private _multisigHashedAddress;
    private _multisigHashedContract?;
    constructor(_multisigHashedAddress: string, signerOrProvider: Signer | ethers.providers.ExternalProvider);
    private _getMultisigHashedContract;
    /**Getters */
    getContract(): Promise<MultiSigHashed>;
    isConfirmed(hash: BytesLike): Promise<boolean>;
    makeHash(destination: string, value: BigNumberish, data: BytesLike): Promise<string>;
    getConfirmationCount(hash: BytesLike): Promise<BigNumberish>;
    getOwners(): Promise<Array<string>>;
    getConfirmations(hash: BytesLike): Promise<Array<string>>;
    getTransaction(hash: BytesLike): Promise<Transaction>;
    getTransactionByIdx(idx: BigNumberish): Promise<Transaction>;
    /**Setters */
    submitTransaction(destination: string, value: BigNumberish, data: BytesLike, overrides: Overrides): Promise<ContractTransaction>;
    confirmTransaction(hash: BytesLike): Promise<ContractTransaction>;
    revokeConfirmation(hash: BytesLike): Promise<ContractTransaction>;
    executeTransaction(hash: BytesLike): Promise<ContractTransaction>;
    /** Helpers */
    static encodeCall(functionName: string, args?: any[]): string;
    static decodeCall(data: string): DecodedCall | null;
}
