import { ContractTransaction, ethers, Signer } from "ethers";
import { ResourceActionsV10 } from "./types";
import { DecodedCall } from "./abiDecoderController";
export declare enum Action {
    PRODUCE = 0,
    PICK_UP = 1,
    DROP_OFF = 2,
    MODIFY = 3,
    MOVE = 4,
    TRANSFER_COMPLETE = 5,
    ACCEPT = 6,
    TRANSFER_CUSTODY = 7,
    TRANSFER_ALL_RIGHTS = 8,
    MEASURE = 9
}
export declare class ResourceActionsController {
    private _signer;
    private _resourceActionsAddress;
    private _resourceActionsContract?;
    constructor(_resourceActionsAddress: string, signerOrProvider: Signer | ethers.providers.ExternalProvider);
    private _getResourceActionsContract;
    /**Getters */
    getContract(): Promise<ResourceActionsV10>;
    getPermission(action: Action, companyOrUserAddress: string): Promise<boolean>;
    getProduceAction(): Promise<Action>;
    getDropOffAction(): Promise<Action>;
    getPickUpAction(): Promise<Action>;
    getModifyAction(): Promise<Action>;
    getMoveAction(): Promise<Action>;
    getTransferCompleteAction(): Promise<Action>;
    getMeasureAction(): Promise<Action>;
    getPermissions(companyOrUserAddress: string): Promise<[
        boolean,
        boolean,
        boolean,
        boolean,
        boolean,
        boolean,
        boolean,
        boolean,
        boolean,
        boolean
    ]>;
    getAllActions(): Promise<[
        Action,
        Action,
        Action,
        Action,
        Action,
        Action,
        Action,
        Action,
        Action,
        Action
    ]>;
    getCompaniesContract(): Promise<string>;
    getCompanyBySignatorie(userAddress: string): Promise<string>;
    /**Setters */
    setCompaniesContract(address: string): Promise<ContractTransaction>;
    setPermission(action: Action, companyAddress: string, allow: boolean): Promise<ContractTransaction>;
    setPermissions(actions: Array<Action>, companyAddress: string, allow: boolean): Promise<ContractTransaction>;
    /** Helpers */
    static encodeCall(functionName: string, args?: any[]): string;
    static decodeCall(data: string): DecodedCall | null;
}
